@@ -18,7 +18,7 @@
  * WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
  * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  *
- * @(#) $Header: /tcpdump/master/tcpdump/llc.h,v 1.17.2.1 2005/04/26 07:27:16 guy Exp $ (LBL)
+ * @(#) $Header: /tcpdump/master/tcpdump/llc.h,v 1.17.2.3 2005/12/01 17:48:25 hannes Exp $ (LBL)
  */
 
 /*
@@ -27,6 +27,7 @@
 
 #define	LLC_U_FMT	3
 #define	LLC_GSAP	1
+#define	LLC_IG	        1 /* Individual / Group */
 #define LLC_S_FMT	1
 
 #define	LLC_U_POLL	0x10
@@ -43,7 +44,7 @@
 #define	LLC_XID		0xaf
 #define	LLC_FRMR	0x87
 
-#define	LLC_S_CMD(is)	(((is) >> 1) & 0x03)
+#define	LLC_S_CMD(is)	(((is) >> 2) & 0x03)
 #define	LLC_RR		0x0001
 #define	LLC_RNR		0x0005
 #define	LLC_REJ		0x0009
@@ -63,6 +64,9 @@
 #ifndef LLCSAP_8021B_G
 #define	LLCSAP_8021B_G		0x03
 #endif
+#ifndef LLCSAP_SNA
+#define	LLCSAP_SNA		0x04
+#endif
 #ifndef LLCSAP_IP
 #define	LLCSAP_IP		0x06
 #endif
